<?php
namespace FM\Service;

use FM\Factory\CardsFactory;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use Doctrine\ORM\EntityManager;

class CardsService {
    
    protected $connection;
    protected $CardsFactory;
    protected $Environment;
    protected $newCode;
    
    public function __construct (EntityManager $entityManager, CardsFactory $CardsFactory, Environment $Environment, NewCode $newCode) {
        $this->connection = $entityManager->getConnection();
        $this->CardsFactory  = $CardsFactory;
        $this->Environment                  = $Environment;
        $this->newCode                      = $newCode;
    }

    public function buscandoTipoLocal(){
        $operadores = $this->CardsFactory->buscaTipoLocal();
        return $operadores;
    }

    public function buscandoLocal(){
        $operadores = $this->CardsFactory->buscaLocal();
        return $operadores;
    }

    public function buscandoChecklist(){
        $operadores = $this->CardsFactory->buscaChecklist();
        return $operadores;
    }

    public function buscandoItensChecklist($parametro){
        $param = array(
            "NRCHECKLIST"   => $parametro['checklist']
        );
        $operadores = $this->CardsFactory->buscaItensChecklist($param);
        return $operadores;
    }

    public function buscandoFuncionario(){
        $operadores = $this->CardsFactory->buscaFuncionario();
        return $operadores;
    }

    public function buscandoCriterioTarefa($parametro){
        $param = array(
            "NRCHECKLIST"   => implode(',', $parametro)
        );
        $operadores = $this->CardsFactory->buscaCriterioTarefa($param);
        return $operadores;
    }

    public function buscandoTarefa($parametro){
        $param = array(
            "NRATIVIDADE"   => implode(',', $parametro['checklist'])
        );
        $operadores = $this->CardsFactory->buscaTarefa($param);

        return $operadores;
    }
    
    public function buscandoCriterioAtividade($param){
        $params = array(
            "NRCHECKLIST" => $param['NRCHECKLIST'],
            "NRATIVIDADECHK" => implode(',', $param['NRATIVIDADECHK']),
            "NRTAREFACHK" => implode(',', $param['NRTAREFACHK'])
        );
        if ($params['NRATIVIDADECHK'] < 1 || $params['NRTAREFACHK'] < 1 ) {
            return [];
        }
        $operadores = $this->CardsFactory->buscaCriterioAtividade($params);
        $retorno = array();
        $valida = array();
        forEach($operadores as $value){
            if(!(in_array($value['DSCRITERIOTAREFA'],$valida))){
                $valida[] = $value['DSCRITERIOTAREFA'];
                $retorno[] = $value;
            }
        }
        return $retorno;
    }
    
    public function buscandoCard($param){
        
        $filtro = array();
        forEach($param as $ind => $dados){
            if($ind == 'TO_CHAR(A.DTHORAAGEND,\'DD/MM/YYYY\')'){
                (strlen($dados) == 21) ? $filtro[] = $ind.' = '.$dados : '';
            }
            else {
                ($dados != null) ? $filtro[] = $ind.' = '.$dados : '';
            }
        }
        
        if (count($filtro) > 0){
            $params = array(
                "FILTRO"   => "WHERE ".implode(' and ', $filtro)
            );
        }
        else {
            $params = array(
                "FILTRO"   => ''
            );
        }
        $operadores = $this->CardsFactory->buscaCard($params);

        return $operadores;
    }
    
    public function insertNovaTarefa($param){
        
        $this->connection->beginTransaction();
        
        try {
            $NRORG = 20;
            forEach($param['DATA'] as $dados){
                $dataFormt = $dados." ".$param['HORAINICIO'];
                $nrchecklistagend = $this->newCode->getCodeByTableName("FCM_CHECKLISTAGEND", $NRORG, 1, 10, true);
                $params = array(
                    "NRCHECKLISTAGEND" => $nrchecklistagend,
                    "NMCHECKLISTAGEND" => $param['NMTAREFA'],
                    "NRLOCALCLIENTE"  => $param['LOCAL'],
                    "NRCHECKLIST"  => $param['CHECKLIST'],
                    "NRFUNCIONARIO" => $param['NRFUNCIONARIO'],
                    "IDSITUACAOAGEND" => 1,
                    "DTHORAAGEND" => $dataFormt, 
                    "OPERADOR" => '000000004280'
                );
                $operadores = $this->CardsFactory->insertNovaTarefa($params);
                forEach($param['TAREFA'] as $dadosTarefa){
                    $nrtarefaagend = $this->newCode->getCodeByTableName("FCM_TAREFAAGEND", $NRORG, 1, 10, true);
                    $params = array(
                        "NRTAREFAAGEND" => $nrtarefaagend,
                        "NRCHECKLISTAGEND" => $nrchecklistagend,
                        "NRTAREFACHK" => $dadosTarefa,
                        "NRFUNCIONARIO" => $param['NRFUNCIONARIO'],
                        "DTHORAAGEND" => $dataFormt, 
                        "DSOBSTAREFAAGEND" => null,
                        "OPERADOR" => '000000004280'
                    );
                    $operadores = $this->CardsFactory->insertNovaTarefa2($params);
                    
                    forEach($param['CRITERIOS'] as $dadosCriterio){
                        $nrcriteriostaragend = $this->newCode->getCodeByTableName("FCM_CRITERIOTARAGEND", $NRORG, 1, 10, true);
                        
                        $parametros = array(
                            "NRCRITERIOTARAGEND" => $nrcriteriostaragend,
                            "NMCRITERIOTARAGEND" => $dadosCriterio['value'],
                            "NRTAREFAAGEND" => $nrtarefaagend,
                            "NRCRITERIOTAREFACHK" => ($dadosCriterio['id'] === $dadosCriterio['value']) ? null : $dadosCriterio['id'],
                            "OPERADOR" => '000000004280'
                        );
                        
                        $operadores = $this->CardsFactory->insertNovaTarefa3($parametros);
                        
                    }
                };
                
                $dataFormt = $dados." ".$param['HORAINICIO'];
                $nrgerenciamentochk = $this->newCode->getCodeByTableName("FCM_GERENCIAMENTOCHK", $NRORG, 1, 10, true);
                $params = array(
                    "NRGERENCIAMENTOCHK" => $nrgerenciamentochk,
                    "NMGERENCIAMENTOCHK" => $param['NMTAREFA'],
                    "NRLOCALCLIENTE"  => $param['LOCAL'],
                    "NRCHECKLIST"  => $param['CHECKLIST'],
                    "NRFUNCIONARIO" => $param['NRFUNCIONARIO'],
                    "DTHORAAGEND" => $dataFormt, 
                    "OPERADOR" => '000000004280',
                    "NRCHECKLISTAGEND" => $nrchecklistagend
                );
                $operadores = $this->CardsFactory->insertNovaTarefa4($params);
                forEach($param['TAREFA'] as $dadosTarefa){
                    
                    $nrtarefaagendchk = $this->newCode->getCodeByTableName("FCM_TAREFAGERCHK", $NRORG, 1, 10, true);
                    $params = array(
                        "NRTAREFAGERCHK" => $nrtarefaagendchk,
                        "NRGERENCIAMENTOCHK" => $nrgerenciamentochk,
                        "NRTAREFACHK" => $dadosTarefa,
                        "NRFUNCIONARIO" => $param['NRFUNCIONARIO'],
                        "DTHORATAREFAGERCHK" => $dataFormt, 
                        "DSOBSTAREFAGERCHK" => null,
                        "OPERADOR" => '000000004280'
                    );
                    $operadores = $this->CardsFactory->insertNovaTarefa5($params);
                    
                    forEach($param['CRITERIOS'] as $dadosCriterio){
                        $nrcriteriostaragerchk = $this->newCode->getCodeByTableName("FCM_CRITERIOTARGERCHK", $NRORG, 1, 10, true);
                        
                        $parametros = array(
                            "NRCRITERIOTARGERCHK" => $nrcriteriostaragerchk,
                            "NMCRITERIOTARGERCHK" => $dadosCriterio['value'],
                            "NRTAREFAGERCHK" => $nrtarefaagendchk,
                            "NRCRITERIOTAREFACHK" => ($dadosCriterio['id'] === $dadosCriterio['value']) ? null : $dadosCriterio['id'],
                            "OPERADOR" => '000000004280'
                        );
                        $operadores = $this->CardsFactory->insertNovaTarefa6($parametros);
                    }
                }
            }
            $this->connection->commit();
            $response = "OK";
        }
        catch(\Exception $e) {
             $this->connection->rollback();
             $response = utf8_decode($e->getMessage());
        }
        return $response;
    }
}
?>