import {
  Metadata, Http, IDictionary,
  IEventParam,
} from '@zeedhi/core';
import {
  Select, Text, IComponentRender, Date,
} from '@zeedhi/common';
import { IterableComponentRender } from '@zeedhi/teknisa-components-common';

export class TarefaController {
  public dateValue: string = '';

  public dadosFiltro: IDictionary = {
    selectTipoTarefa: [],
    selectTipoLocal: [],
    selectAndar: [],
    selectStatus: [],
    selectFuncionario: [],
  };

  public list2: IDictionary = [];

  public dadosCard: IComponentRender[] = [];

  public setDados(nome: string, cod: number) {
    return {
      name: nome,
      value: cod,
    };
  }

  public dataFilter: string = '';

  public getCards() {
    const iterable = Metadata.getInstance<IterableComponentRender>('iterable_Card_Tasck');
    iterable.datasource.data = [];
    Http.post('/getCard', { variavel1: this.filtroCards() }).then((response: IDictionary) => {
      if (response.data.dataset.cards.length === 0) {
        iterable.noDataSlot = [
          {
            name: 'no-data',
            component: 'ZdRow',
            cssClass: 'zd-mt-7',
            children: [
              {
                name: 'no-data',
                component: 'ZdCol',
                align: 'center',
                cssClass: 'zd-mt-7',
                children: [
                  {
                    name: 'TextCarrengoDados',
                    component: 'ZdText',
                    text: 'Nunhum dado disponível no momento',
                  },
                ],
              },
            ],
          },
        ];
      }
      response.data.dataset.cards.forEach((dados: IDictionary) => {
        this.dadosFiltro.selectTipoTarefa.push(this.setDados(dados.NMCHECKLISTAGEND, dados.NRCHECKLISTAGEND));
        this.dadosFiltro.selectTipoLocal.push(this.setDados(dados.NMLOCALCLIENTE, dados.NRLOCALCLIENTE));
        this.dadosFiltro.selectTipoLocal.push(this.setDados(dados.NMLOCALCLIENTE2, dados.NRLOCALCLIENTEPAI));
        this.dadosFiltro.selectAndar.push(this.setDados(dados.NMCHECKLIST, dados.NRCHECKLIST));
        this.dadosFiltro.selectStatus.push(this.setDados(dados.NMIDSITUACAOAGEND, dados.IDSITUACAOAGEND));
        this.dadosFiltro.selectFuncionario.push(this.setDados(dados.NMFUNCIONARIO, dados.NRFUNCIONARIO));
        let dataHora = dados.DTHORAAGEND.split(' ');
        dataHora = `${dataHora[0].split('-')[2]}-${dataHora[0].split('-')[1]}-${dataHora[0].split('-')[0]} ${dataHora[1].substr(0, 5)}`;
        iterable.datasource.data.push({
          nr: dados.NRCHECKLISTAGEND,
          nome: dados.NMCHECKLISTAGEND,
          local: dados.NMLOCAL,
          horario: dataHora,
          funcionario: (dados.NMFUNCIONARIO.length > 22) ? `${dados.NMFUNCIONARIO.substr(0, 40)}...` : dados.NMFUNCIONARIO,
          statu: dados.NMIDSITUACAOAGEND,
        });
      });
    });
  }

  public filtroCards() {
    const data = Metadata.getInstance<Date>('selectData').value;
    return {
      'A.NRCHECKLISTAGEND': Metadata.getInstance<Select>('selectTipoTarefa').value,
      'C.NRLOCALCLIENTE': Metadata.getInstance<Select>('selectTipoLocal').value,
      'A.NRCHECKLIST': Metadata.getInstance<Select>('selectAndar').value,
      'A.IDSITUACAOAGEND': Metadata.getInstance<Select>('selectStatus').value,
      'A.NRFUNCIONARIO': Metadata.getInstance<Select>('selectFuncionario').value,
      'TO_CHAR(A.DTHORAAGEND,\'DD/MM/YYYY\')': ((data != null) ? `TO_CHAR('${data}')` : null),
    };
  }

  public getParent(component: IEventParam<any>, nameComponent: string): any {
    if (component.component === nameComponent) {
      return component;
    }
    if (component.parent) {
      return this.getParent(component.parent, nameComponent);
    }
    return null;
  }

  public add(nome: string, valor: number) {
    return {
      name: nome,
      value: valor,
    };
  }

  public filtroTipoTarefa({ component }: IEventParam<Select>) {
    component.datasource.data = this.dadosFiltro[component.name];
  }

  public mudaTitulo(dig: string = 'Test') {
    const selectObject = Metadata.getInstance<Text>('TituloPrincipal');
    selectObject.text = dig;
  }

  public styleColor({ component }: IEventParam<Text>) {
    if (component.text === 'Pendente') {
      component.text = '<span style="color: #E9C46A;">Pendente</span>';
    } else if (component.text === 'Em Andamento') {
      component.text = '<span style="color: #E9C46A;">Em Andamento</span>';
    } else if (component.text === 'Concluido') {
      component.text = '<span style="color: #E9C46A;">Concluido</span>';
    } else {
      component.text = '<span style="color: #E9C46A;">Cancelado</span>';
    }
  }
}
